@@ -1,4 +1,5 @@
 import json
+from typing import Optional
 from urllib.parse import parse_qs, quote, urlencode, urlparse, urlunparse
 
 from django import shortcuts
@@ -47,7 +48,7 @@ def redirect(to):
         return shortcuts.redirect(f"/{to}")
 
 
-def add_query_params(url, params):
+def add_query_params(url: str, params: dict) -> str:
     parsed_url = urlparse(url)
     query_params = parse_qs(parsed_url.query)
     query_params.update(params)
@@ -108,13 +109,16 @@ def get_frontend_url(request, urlname, **kwargs):
     return default_get_frontend_url(request, urlname, **kwargs)
 
 
-def headed_redirect_response(viewname):
+def headed_redirect_response(viewname, query=None):
     """
     In some cases, we're redirecting to a non-headless view. In case of
     headless-only mode, that view clearly does not exist.
     """
     try:
-        return HttpResponseRedirect(reverse(viewname))
+        url = reverse(viewname)
+        if query:
+            url = add_query_params(url, query)
+        return HttpResponseRedirect(url)
     except NoReverseMatch:
         if allauth_settings.HEADLESS_ONLY:
             # The response we would be rendering here is not actually used.
@@ -122,5 +126,11 @@ def headed_redirect_response(viewname):
         raise
 
 
-def is_headless_request(request: HttpRequest) -> bool:
-    return bool(getattr(getattr(request, "allauth", None), "headless", None))
+def is_headless_request(request: HttpRequest) -> Optional[str]:
+    """
+    Returns the headless client type (app/browser)in case of a headless
+    request.
+    """
+    return getattr(
+        getattr(getattr(request, "allauth", None), "headless", None), "client", None
+    )
