@@ -1,5 +1,7 @@
+from django.test import TestCase
+
 from allauth.socialaccount.tests import OAuth2TestsMixin
-from allauth.tests import MockedResponse, TestCase
+from allauth.tests import MockedResponse
 
 from .provider import FirefoxAccountsProvider
 
@@ -16,3 +18,6 @@ class FirefoxAccountsTests(OAuth2TestsMixin, TestCase):
             "email":"user@example.com"
         }""",
         )
+
+    def get_expected_to_str(self):
+        return "user@example.com"
