@@ -8,9 +8,6 @@ class NaverAccount(ProviderAccount):
     def get_avatar_url(self):
         return self.account.extra_data.get("profile_image")
 
-    def to_str(self):
-        return self.account.extra_data.get("nickname", self.account.uid)
-
 
 class NaverProvider(OAuth2Provider):
     id = "naver"
